package jqplayground

import (
	"github.com/charmbracelet/bubbletea"
)

func (b Bubble) Init() tea.Cmd {
	return b.queryinput.Init()
}
